PRO eprd

;*************************************************************************
; Name: eprd
;
; Purpose:
;   This rountine is the main driver to plot the Effective Radius Differences.
;    The 1.6-2.1 and 3.7-2.1 differences can be plotted as well as the 1.6, 2.1, and 3.7.
;    this code will read lat/lon information from the supplied MOD03 file.
;
; Inputs:
;  Environmental variables:
;   Year, Day, Time:  Date of the granule being plotted.
;   Output_Path    :  Directory to store the image produced.
;   Input_Path     :  Directory where the L2 file is stored.
;  Passed:
;   None.
;
; Outputs:
;  None. 
;
; Required programs:
;  plot_eprd.pro
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
; it freely, subject to the following restrictions:
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************


;*************************************************************************
;  Define the Time, Julian Day, and Year, which will be used in creating 
;  titles for the plots, and output file names.
;*************************************************************************
year = GETENV('Year')
day  = GETENV('Day' )
time = GETENV('Time')


;*************************************************************************
; Define the output directory:
;*************************************************************************
output_dir = GETENV('Output_Path')


;*************************************************************************
; Define the files that contain the Ancillary data, including path.  
;*************************************************************************
;Create the Ancillary filenames array:
MOD06filenames   = StrArr(1)

;Define the overall path where the files reside:
MOD06Path = GETENV('Input_Path')
;Define the MOD06 File Name:
file_spec = MOD06Path+'MOD06_*'+ Year + Day + '.' + Time + '*' 
result = FINDFILE(file_spec)
MOD06filenames[0] = strcompress(result(0))
print, MOD06filenames


;*************************************************************************
;Since these files have internal geolocation arrays, set them equal to
; the Ancifilenames:
;*************************************************************************
Geofilenames = StrArr(1)
Geofilenames[0] = MOD06filenames[0]


;*************************************************************************
; Define the Ancillary SDSs to plot.  If the SDS is to be plotted, set 
; the value to 1, if not, set to 0.
;*************************************************************************
numSDS      = 4
PlotAnci    = IntArr(numSDS)
PlotAnci[0] = 1 ; Effective Particle Rad Diff, 1.6-2.1
PlotAnci[1] = 1 ; Effective Particle Rad Diff, 3.7-2.1
PlotAnci[2] = 1 ; Effective Particle Rad, 1.6
PlotAnci[3] = 1 ; Effective Particle Rad, 3.7

;*************************************************************************
; Definition of the names to use in the output file names for each SDS:
;*************************************************************************
AnciOutName    = StrArr(numSDS)
AnciOutName[0] = 'EPRD_1.6-2.1'
AnciOutName[1] = 'EPRD_3.7-2.1'
AnciOutName[2] = 'EPR_1.6'
AnciOutName[3] = 'EPR_3.7'


;*************************************************************************
; Definition of the names to use in the output file names for each SDS:
;*************************************************************************
TitleName    = StrArr(numSDS)
TitleName[0] = '1.6 - 2.1 Micron Effective Radius Difference'
TitleName[1] = '3.7 - 2.1 Micron Effective Radius Difference'
TitleName[2] = '1.6 Micron Effective Radius Retrieval'
TitleName[3] = '3.7 Micron Effective Radius Retrieval'

;*************************************************************************
; Difference Flag, Is this a difference plot, yes/no, 1/0:
;*************************************************************************
diff_flag = IntArr(numSDS)
diff_flag[0] = 1 ;Re Diff 1.6-2.1
diff_flag[1] = 1 ;Re Diff 3.7-2.1
diff_flag[2] = 0 ;Re 1.6
diff_flag[3] = 0 ;Re 3.7


;*************************************************************************
; Define the SDS limits, as [min, max]:
;*************************************************************************
AnciSDSLimits      = FltArr(numSDS,2)
AnciSDSLimits[0,0] =  -5.0 ;Re Diff 2.1-1.6, min
AnciSDSLimits[0,1] =   5.0 ;Re Diff 2.1-1.6, max
AnciSDSLimits[1,0] =  -5.0 ;Re Diff 3.7-2.1, min
AnciSDSLimits[1,1] =   5.0 ;Re Diff 3.7-2.1, max 
AnciSDSLimits[2,0] =   0.0 ;Re 1.6, min
AnciSDSLimits[2,1] =  40.0 ;Re 1.6, max
AnciSDSLimits[3,0] =   0.0 ;Re 3.7, min
AnciSDSLimits[3,1] =  40.0 ;Re 3.7, max 

;*************************************************************************
; Define the limit around zero to gray out of the difference plots.
;*************************************************************************
delta_zero      = FltArr(numSDS,2)
delta_zero[0,0] = -1.0 ; Re Diff 1.6-2.1, min
delta_zero[0,1] =  1.0 ; Re Diff 1.6-2.1, max
delta_zero[1,0] = -1.0 ; Re Diff 3.7-2.1, min
delta_zero[1,1] =  1.0 ; Re Diff 3.7-2.1, max
delta_zero[2,0] = -1.0 ; Re 1.6, min
delta_zero[2,1] =  1.0 ; Re 1.6, max
delta_zero[3,0] = -1.0 ; Re 3.7, min
delta_zero[3,1] =  1.0 ; Re 3.7, max

;*************************************************************************
; Choose the number of levels to be included on the color bar:
;*************************************************************************
Num_CB_Levels    = IntArr(numSDS)
Num_CB_Levels[0] = 5 ;Re Diff 2.1-1.6
Num_CB_Levels[1] = 5 ;Re Diff 3.7-2.1
Num_CB_Levels[2] = 5 ;;Re 1.6
Num_CB_Levels[3] = 5 ;Re 3.7


;*************************************************************************
; Define the SDS units:
;*************************************************************************
SDSunits      = StrArr(numSDS)
SDSunits[0]   = 'microns'
SDSunits[1]   = 'microns'
SDSunits[2]   = 'microns'
SDSunits[3]   = 'microns'

;*************************************************************************
; Definition of the names of the Ancillary SDS as defined in the HDF file.
;*************************************************************************
AnciSDSName    = StrArr(numSDS)
AnciSDSName[0] = 'Effective_Radius_Difference'
AnciSDSName[1] = 'Effective_Radius_Difference'
AnciSDSName[2] = 'Effective_Radius_Difference'
AnciSDSName[3] = 'Effective_Radius_Difference'

;*************************************************************************
;Multi dimension choice:
; Single banded have MDchoice = 0, Multi banded start with 0.
;*************************************************************************
MDchoice    = IntArr(numSDS)
MDchoice[0] = 0 ; Re Diff 1.6-2.1
MDchoice[1] = 1 ; Re Diff 3.7-2.1
MDchoice[2] = 0 ; Re 1.6
MDchoice[3] = 1 ; Re 3.7

;*************************************************************************
; Use the light colorscale (abrupt green to yellow), yes/no, 1/0:
;*************************************************************************
light_scale    = IntArr(numSDS)
light_scale[0] = 1 ; Re Diff 1.6-2.1
light_scale[1] = 1 ; Re Diff 3.7-2.1
light_scale[2] = 0 ; Re 1.6
light_scale[3] = 0 ; Re 3.7



;*************************************************************************
; End of definition section, make changes to the rest of the code at
; your own discretion.  If you wish to define a lat/lon box to plot,
; define it in the section below and choose the program call which
; includes the limits in the call.
;*************************************************************************




;*************************************************************************
; Loop over the SDSs, plotting only the desired ones.
;*************************************************************************
for icnt = 0, numSDS-1 do begin

   ;*************************************************************************
   ; Define the name of the output image file, including path:
   ;*************************************************************************
   AnciOutFileName = output_dir+AnciOutName[icnt]+'.'+Year+'.'+Day+'.'+Time+'.ps'

   ;*************************************************************************
   ; Add a title to the plot if desired. Ex. titlestring ='Title'
   ;*************************************************************************
   ;titlestring = 'Year 2000, Day 110, combined granules 0855 and 0900'
   titlestring = TitleName[icnt]+' ('+SDSunits[icnt]+')'+ $
                 '  Day '+Day+', '+Year+' '+Time+' UTC'

   ;*************************************************************************
   ;If you would like to specify the lat/lons to plot, please specify them
   ;   here.  This option is to be used if you want to specify a lat/lon box
   ;   of the granule(s) to plot.  The format is as follows:
   ;   limits=[NorthBound,WestBound,SouthBound,EastBound]
   ;If you want the program to compute the bounds, please comment this 
   ;*************************************************************************
   ;limits=[-10.,110.,-40.,160.]; Australia
   limits=0

   ;*************************************************************************
   ;Call the program, bearing in mind that only the postscript output is 
   ; available.  The basic call is as follows:
   ;*************************************************************************
   ;Since these are two dim, set multidim_choice to 0:
   multidim_choice = MDChoice[icnt]
   ;Test to see if this SDS should be plotted:
   print, ''
   IF (PlotAnci[icnt] eq 1) then begin
      ;Call the plotting code:
      print, 'Plotting ',TitleName[icnt]
      SDS_limits = [AnciSDSLimits[icnt,0],AnciSDSLimits[icnt,1]]
      delta_z    = [delta_zero[icnt,0],delta_zero[icnt,1]]
      plot_eprd, MOD06filenames, AnciSDSName[icnt],             $
                   AnciOutFileName, SDS_limits, limits,           $
                   titlestring, multidim_choice,diff_flag[icnt],  $
                   Num_CB_Levels[icnt],light_scale[icnt],delta_z, $
                   /ps, /notation
   ENDIF ELSE BEGIN
      print, 'Skipping ',TitleName[icnt]
   ENDELSE

;*************************************************************************
;End the looping:
;*************************************************************************
endfor


END
